@@ -2,8 +2,7 @@ use crate::constants::{DEFAULT_ALGORITHM, DEFAULT_BREADTH, DEFAULT_COUNTER, DEFA
 use hmacsha::{HmacSha, ShaTypes};
 
 /// Convert a `u64` value to an array of 8 elements of 8-bit.
-#[inline(always)]
-fn u64_to_8_length_u8_array(input: u64) -> [u8; 8] {
+const fn u64_to_8_length_u8_array(input: u64) -> [u8; 8] {
     input.to_be_bytes()
 }
 
@@ -27,6 +26,7 @@ fn make_opt(secret: &[u8], digits: u32, counter: u64, algorithm: &ShaTypes) -> S
 }
 
 /// The Options for the HOTP `make` function.
+#[derive(Clone, Copy)]
 pub enum MakeOption<'a> {
     /// The default case. `Counter = 0` and `Digits = 6`.
     Default,
@@ -45,6 +45,7 @@ pub enum MakeOption<'a> {
 }
 
 /// The Options for the HOTP and TOTP `check` function.
+#[derive(Clone, Copy)]
 pub enum CheckOption<'a> {
     /// The default case. `Counter = 0` and `Breadth = 0`.
     Default,
@@ -70,7 +71,7 @@ pub struct Hotp<'a> {
 }
 
 impl<'a> Hotp<'a> {
-    pub fn new(secret: &'a str) -> Self {
+    pub const fn new(secret: &'a str) -> Self {
         Self { secret }
     }
 
@@ -109,30 +110,30 @@ impl<'a> Hotp<'a> {
                 self.secret().as_bytes(),
                 DEFAULT_DIGITS,
                 DEFAULT_COUNTER,
-                &DEFAULT_ALGORITHM,
+                DEFAULT_ALGORITHM,
             ),
             MakeOption::Counter(counter) => make_opt(
                 self.secret().as_bytes(),
                 DEFAULT_DIGITS,
                 counter,
-                &DEFAULT_ALGORITHM,
+                DEFAULT_ALGORITHM,
             ),
             MakeOption::Digits(digits) => make_opt(
                 self.secret().as_bytes(),
                 digits,
                 DEFAULT_COUNTER,
-                &DEFAULT_ALGORITHM,
+                DEFAULT_ALGORITHM,
             ),
             MakeOption::Full {
                 counter,
                 digits,
                 algorithm,
-            } => make_opt(self.secret().as_bytes(), digits, counter, &algorithm),
+            } => make_opt(self.secret().as_bytes(), digits, counter, algorithm),
             MakeOption::Algorithm(algorithm) => make_opt(
                 self.secret().as_bytes(),
                 DEFAULT_DIGITS,
                 DEFAULT_COUNTER,
-                &algorithm,
+                algorithm,
             ),
         }
     }
@@ -175,7 +176,7 @@ impl<'a> Hotp<'a> {
             let code = self.make(MakeOption::Full {
                 counter: i,
                 digits: otp.len() as u32,
-                algorithm: &algorithm,
+                algorithm,
             });
             if code == otp {
                 return true;
@@ -185,7 +186,7 @@ impl<'a> Hotp<'a> {
     }
 
     /// Get a reference to the hotp's  secret.
-    pub fn secret(&self) -> &&'a str {
+    pub const fn secret(&self) -> &&'a str {
         &self.secret
     }
 }
@@ -195,7 +196,7 @@ mod tests {
     use hmacsha::ShaTypes;
 
     use super::{u64_to_8_length_u8_array, CheckOption, Hotp, MakeOption};
-    use crate::constants::*;
+    use crate::constants::DEFAULT_ALGORITHM;
 
     #[test]
     fn make_test() {
